==> haskell-yesod-persistent-1.6.0.8-488-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-persistent
version:              1.6.0.8
visibility:           public
id:                   yesod-persistent-1.6.0.8-HpeBn2s4WoZ5QIv4pKLXr9
key:                  yesod-persistent-1.6.0.8-HpeBn2s4WoZ5QIv4pKLXr9
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>

category:             Web, Yesod, Database
abi:                  d6da11075f4cf45c9cb785075dd94f62
exposed:              True
exposed-modules:      Yesod.Persist Yesod.Persist.Core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-persistent
hs-libraries:         HSyesod-persistent-1.6.0.8-HpeBn2s4WoZ5QIv4pKLXr9
depends:
    base-4.17.2.1 blaze-builder-0.4.4.1-3BvkKG3rmZ5F6dgS70Rje7
    conduit-1.3.6.1-793fWFbadkvFwVYySs1ukE
    persistent-2.14.5.2-2baaq0U3ooO1367vv6KzHR
    resource-pool-0.2.3.2-BxDvxmo4sDl6W5uOYQs4yN
    resourcet-1.2.6-6Q9ZdpuTS1aCzu997x6CHk transformers-0.5.6.2
    yesod-core-1.6.27.1-5wpbNar1YRPL4LYUQcYFNh

haddock-interfaces:
    /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock

haddock-html:         /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-persistent-1.6.0.8-489-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-persistent
version:              1.6.0.8
visibility:           public
id:                   yesod-persistent-1.6.0.8-44NQYwsEDzIIzqI9AfkVTv
key:                  yesod-persistent-1.6.0.8-44NQYwsEDzIIzqI9AfkVTv
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>

category:             Web, Yesod, Database
abi:                  bc9bb4dc0e7ef1b84b44fbf26386d161
exposed:              True
exposed-modules:      Yesod.Persist Yesod.Persist.Core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-persistent
hs-libraries:         HSyesod-persistent-1.6.0.8-44NQYwsEDzIIzqI9AfkVTv
depends:
    base-4.17.2.1 blaze-builder-0.4.4.1-1jE2jTKoqGH3aj9MBDpFLw
    conduit-1.3.6.1-GPe8u3RYhCEKxuB1doj8qM
    persistent-2.14.5.2-6AC0MQSbfCW4kELDWmexci
    resource-pool-0.2.3.2-HjPUAD1l5JbEZWfwE7kb5C
    resourcet-1.2.6-8zJ4onmdcE7Bb7T1oAZJH7 transformers-0.5.6.2
    yesod-core-1.6.27.1-7UB6a2H67dyKWAATJGQFCL

haddock-interfaces:
    /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock

haddock-html:         /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
